@@ -641,9 +641,10 @@ ewscal_set_timezone (ESoapMessage *msg,
 
 void
 ewscal_set_meeting_timezone (ESoapMessage *msg,
-			     ICalTimezone *icaltz)
+			     ICalTimezone *icaltz,
+			     ICalComponent *icomp)
 {
-	ICalComponent *comp;
+	ICalComponent *comp, *copy;
 	ICalComponent *xstd, *xdaylight;
 	ICalDuration *duration;
 	const gchar *location;
@@ -657,14 +658,18 @@ ewscal_set_meeting_timezone (ESoapMessage *msg,
 	if (!comp)
 		return;
 
+	/* Clamp the time zone component, to get the relevant part only */
+	copy = i_cal_component_clone (comp);
+	g_clear_object (&comp);
+	comp = copy;
+	e_cal_util_clamp_vtimezone_by_component (comp, icomp);
+
 	/* Exchange needs a BaseOffset, followed by either *both*
 	 * Standard and Daylight zones, or neither of them. If there's
 	 * more than one STANDARD or DAYLIGHT component in the VTIMEZONE,
 	 * we ignore the extra. So fully-specified timezones including
 	 * historical DST rules cannot be handled by Exchange. */
 
-	/* FIXME: Walk through them all to find the *latest* ones, like
-	 * i_cal_timezone_get_tznames_from_vtimezone() does. */
 	xstd = i_cal_component_get_first_component (comp, I_CAL_XSTANDARD_COMPONENT);
 	xdaylight = i_cal_component_get_first_component (comp, I_CAL_XDAYLIGHT_COMPONENT);
 
@@ -1284,7 +1289,7 @@ convert_vevent_calcomp_to_xml (ESoapMessage *msg,
 	} else {
 		e_ews_message_replace_server_version (msg, E_EWS_EXCHANGE_2007_SP1);
 
-		ewscal_set_meeting_timezone (msg, tzid_start);
+		ewscal_set_meeting_timezone (msg, tzid_start, icomp);
 	}
 
 	e_soap_message_end_element (msg); /* "CalendarItem" */
@@ -1523,31 +1528,14 @@ convert_vevent_component_to_updatexml (ESoapMessage *msg,
 	gboolean dt_start_changed = FALSE, dt_end_changed = FALSE, dt_changed;
 	gboolean dt_start_changed_timezone_name = FALSE, dt_end_changed_timezone_name = FALSE;
 	gboolean satisfies, rsvp_requested = TRUE, is_all_day_event = FALSE;
-	gchar *recid;
 
-	/* Modifying a recurring meeting ? */
-	if (e_cal_util_component_has_property (icomp_old, I_CAL_RRULE_PROPERTY)) {
-		/* A single occurrence ? */
-		prop = i_cal_component_get_first_property (icomp, I_CAL_RECURRENCEID_PROPERTY);
-		if (prop != NULL) {
-			recid = i_cal_property_get_value_as_string (prop);
-			e_ews_message_start_item_change (
-				msg,
-				E_EWS_ITEMCHANGE_TYPE_OCCURRENCEITEM,
-				convert_data->item_id,
-				convert_data->change_key,
-				e_cal_backend_ews_rid_to_index (
-					convert_data->default_zone,
-					recid,
-					icomp_old,
-					NULL));
-			g_object_unref (prop);
-			g_free (recid);
-		} else {
-			e_ews_message_start_item_change (
-				msg, E_EWS_ITEMCHANGE_TYPE_ITEM,
-				convert_data->item_id, convert_data->change_key, 0);
-		}
+	if (convert_data->change_type == E_EWS_ITEMCHANGE_TYPE_OCCURRENCEITEM && convert_data->index > 0) {
+		e_ews_message_start_item_change (
+			msg,
+			convert_data->change_type,
+			convert_data->item_id,
+			convert_data->change_key,
+			convert_data->index);
 	} else {
 		e_ews_message_start_item_change (msg, E_EWS_ITEMCHANGE_TYPE_ITEM,
 			convert_data->item_id, convert_data->change_key, 0);
@@ -1836,7 +1824,7 @@ convert_vevent_component_to_updatexml (ESoapMessage *msg,
 		e_ews_message_replace_server_version (msg, E_EWS_EXCHANGE_2007_SP1);
 
 		e_ews_message_start_set_item_field (msg, "MeetingTimeZone", "calendar", "CalendarItem");
-		ewscal_set_meeting_timezone (msg, tzid_start ? tzid_start : convert_data->default_zone);
+		ewscal_set_meeting_timezone (msg, tzid_start ? tzid_start : convert_data->default_zone, icomp);
 		e_ews_message_end_set_item_field (msg);
 	}
 
