@@ -28,6 +28,19 @@ e_ews_debug_get_log_level (void)
 	return level;
 }
 
+void
+e_ews_debug_print (const gchar *format,
+		   ...)
+{
+	if (e_ews_debug_get_log_level () != 0) {
+		va_list args;
+
+		va_start (args, format);
+		e_util_debug_printv ("EWS", format, args);
+		va_end (args);
+	}
+}
+
 const gchar *
 e_ews_connection_get_server_version_string (EEwsConnection *cnc)
 {
@@ -79,7 +92,11 @@ print_header (const gchar *name,
 	      const gchar *value,
 	      gpointer user_data)
 {
-	fprintf (user_data, "%s: %s\n", name, value);
+	gchar *header = g_strconcat (name, ": ", value, NULL);
+
+	fprintf (user_data, "%s\n", e_ews_debug_redact_headers ('<', header));
+
+	g_free (header);
 }
 
 static void
